package com.miaxis.system.controller.h5;

import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.qustion.domain.QuestionInfo;
import com.miaxis.qustion.service.IQuestionInfoService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 【题库】Controller
 *
 * @author miaxis
 * @date 2021-10-20
 */
@RestController
@RequestMapping("/qustion/info")
@Api(tags={"【小程序-题库】"})
public class QuestionInfoController extends BaseController{
    @Autowired
    private IQuestionInfoService questionInfoService;

    /**
     * 查询题库列表
     */
    @GetMapping("/list")
    @ApiOperation("查询题库列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<QuestionInfo> list(@ModelAttribute QuestionInfo questionInfo){
        startPage();
        List<QuestionInfo> list = questionInfoService.selectQuestionInfoList(questionInfo);
        return toResponsePageInfo(list);
    }

//    /**
//     * 导出题库列表
//     */
//    @Log(title = "题库", businessType = BusinessTypeEnum.EXPORT)
//    @GetMapping("/export")
//    @ApiOperation("导出题库列表Excel")
//    public Response<String> export(@ModelAttribute QuestionInfo questionInfo){
//        List<QuestionInfo> list = questionInfoService.selectQuestionInfoList(questionInfo);
//        ExcelUtil<QuestionInfo> util = new ExcelUtil<QuestionInfo>(QuestionInfo.class);
//        return util.exportExcel(list, "info");
//    }

    /**
     * 获取题库详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("获取题库详细信息")
    public Response<QuestionInfo> getInfo(
            @ApiParam(name = "id", value = "题库参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(questionInfoService.getById(id));
    }

    /**
     * 新增题库
     */
//    @PreAuthorize("@ss.hasPermi('qustion:info:add')")
//    @Log(title = "题库", businessType = BusinessTypeEnum.INSERT)
//    @PostMapping
//    @ApiOperation("新增题库")
//    public Response<Integer> add(@RequestBody QuestionInfo questionInfo){
//        return toResponse(questionInfoService.save(questionInfo) ? 1 : 0);
//    }

    /**
     * 修改题库
     */
//    @PreAuthorize("@ss.hasPermi('qustion:info:edit')")
//    @Log(title = "题库", businessType = BusinessTypeEnum.UPDATE)
//    @PutMapping
//    @ApiOperation("修改题库")
//    public Response<Integer> edit(@RequestBody QuestionInfo questionInfo){
//        return toResponse(questionInfoService.updateById(questionInfo) ? 1 : 0);
//    }

    /**
     * 删除题库
     */
//    @PreAuthorize("@ss.hasPermi('qustion:info:remove')")
//    @Log(title = "题库", businessType = BusinessTypeEnum.DELETE)
//	@DeleteMapping("/{ids}")
//    @ApiOperation("删除题库")
//    public  Response<Integer> remove(
//            @ApiParam(name = "ids", value = "题库ids参数", required = true)
//            @PathVariable Long[] ids
//    ){
//        return toResponse(questionInfoService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
//    }
}
