package com.miaxis.wx.service.impl;

import cn.hutool.core.img.ImgUtil;
import cn.hutool.core.io.FileUtil;
import cn.hutool.extra.qrcode.QrCodeUtil;
import cn.hutool.extra.qrcode.QrConfig;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.utils.http.HttpUtils;
import com.miaxis.feign.dto.WxQrTicket;
import com.miaxis.feign.service.IWxSendService;
import com.miaxis.spread.domain.WxSpreadRelation;
import com.miaxis.spread.service.IWxSpreadRelationService;
import com.miaxis.wx.service.IWxMessageEvenService;
import com.miaxis.wx.service.IWxTicketService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.awt.*;
import java.io.File;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * @author wwl
 * @version 1.0
 * @date 2021/10/27 14:35
 */
@Service
@Slf4j
@RequiredArgsConstructor
public class WxMessageEvenServiceImpl implements IWxMessageEvenService {

    private final RedisTemplate redisTemplate;

    private final IWxSendService wxSendService;

    private final IWxTicketService wxTicketService;

    private final IWxSpreadRelationService wxSpreadRelationService;

    @Value("${file.ticketPath}")
    private String ticketPath;

    @Value("${wxgzh.materialUrl}")
    private String materialUrl;

    @Value("${cos.bucketName}")
    private String bucketName;

    @Value("${cos.path}")
    private String path;

    @Value("${cos.preffix}")
    private String preffix;


    /**
     * 扫码关注事件
     * @param fromUserName 发送方帐号（一个OpenID）
     * @param ticket 二维码的ticket
     * @return
     */
    @Override
    public String scanSubscribeEvent(String fromUserName, String ticket) {

        String message = "";
        //判断是否存在父级推广关系
        List<WxSpreadRelation> spreadRelations = wxSpreadRelationService.list(new QueryWrapper<WxSpreadRelation>().eq("openid", fromUserName));
        if (spreadRelations.isEmpty()){
            String openid = (String) redisTemplate.opsForValue().get(Constants.GZH_TICKET_KEY + ticket);
            //保存推广关系表
            WxSpreadRelation wxSpreadRelation = new WxSpreadRelation();
            wxSpreadRelation.setOpenid(fromUserName);
            wxSpreadRelation.setParentOpenid(openid);
            wxSpreadRelationService.save(wxSpreadRelation);
            message = "已成功绑定推广关系！";
        }else {
            message = "已存在推广关系！";
        }
        return message;
    }


    /**
     * click获取推广二维码事件
     * @param fromUserName 发送方帐号（一个OpenID）
     * @param token 凭证
     * @return
     */
    @Override
    public String gainTicketEvent(String fromUserName,String token) {

        // 根据fromUserName查询缓存 判断用户推广码是否过期
        if (redisTemplate.hasKey(Constants.GZH_MATERIAL_KEY + fromUserName)){
            String mediaId = (String) redisTemplate.opsForValue().get(Constants.GZH_MATERIAL_KEY + fromUserName);
            return mediaId;
        }

        //生成带参数二维码ticket（永久）
        WxQrTicket wxQrTicket = new WxQrTicket();
        wxQrTicket.setExpire_seconds(259200);//3天
        wxQrTicket.setAction_name("QR_SCENE");//临时
        JSONObject jsonObject1 = new JSONObject();
        JSONObject jsonObject2 = new JSONObject();
        jsonObject1.put("scene_id","123");
        jsonObject2.put("scene",jsonObject1);
        wxQrTicket.setAction_info(jsonObject2);
        String wxTicketResult = wxSendService.generateTicket(token, wxQrTicket);
        JSONObject jsonStr = JSONObject.parseObject(wxTicketResult);
        log.info("---------ticket-------" + jsonStr);

        //获取用户信息
        String userInfoResult = wxSendService.userInfo(token, fromUserName, "zh_CN");
        JSONObject userInfo = JSONObject.parseObject(userInfoResult);
        log.info("---------userInfo-------" + userInfo);

        //根据ticket生成二维码图片存储
        File ticketFile = QrCodeUtil.generate(
                jsonStr.getString("url"), //二维码内容
                QrConfig.create().setImg(ticketPath + "logo.jpg"), //附带logo
                FileUtil.file(ticketPath + fromUserName + ".jpg")//写出到的文件
        );

        ImgUtil.pressImage(
                FileUtil.file(ticketPath+"jinpai.jpg"),
                FileUtil.file(ticketPath+fromUserName+"_img.jpg"),
                ImgUtil.read(FileUtil.file(ticketPath+fromUserName+".jpg")), //水印图片
                0, //x坐标修正值。 默认在中间，偏移量相对于中间偏移
                -360, //y坐标修正值。 默认在中间，偏移量相对于中间偏移
                1.0f
        );

        ImgUtil.pressText(
                FileUtil.file(ticketPath+fromUserName+"_img.jpg"),
                FileUtil.file(ticketPath+fromUserName+"_text.jpg"),
                userInfo.getString("nickname"), Color.red, //文字
                new Font("黑体", Font.BOLD, 60), //字体
                0, //x坐标修正值。 默认在中间，偏移量相对于中间偏移
                400, //y坐标修正值。 默认在中间，偏移量相对于中间偏移
                0.8f//透明度：alpha 必须是范围 [0.0, 1.0] 之内（包含边界值）的一个浮点数字
        );


        try {
            File textFile = new File(ticketPath + fromUserName+"_text.jpg");
            //上传素材
            String path = materialUrl + token + "&type=image";
            String result = HttpUtils.connectHttpsByPost(path,textFile);
            result = result.replaceAll("[\\\\]", "");
            JSONObject resultJSON = JSONObject.parseObject(result);
            log.info("------result:" + resultJSON);

            //缓存用户推广码相关信息
            redisTemplate.opsForValue().set(Constants.GZH_TICKET_KEY+jsonStr.getString("ticket"),fromUserName,259200, TimeUnit.SECONDS);
            redisTemplate.opsForValue().set(Constants.GZH_MATERIAL_KEY+fromUserName,resultJSON.getString("media_id"),259200, TimeUnit.SECONDS);

            //删除服务器文件
            File imgFile = new File(ticketPath + fromUserName+"_img.jpg");
            if (ticketFile.exists() && imgFile.exists() && textFile.exists()) {
                if (ticketFile.delete()) {
                    log.info("删除:" + ticketFile.getName() + "成功！");
                } else {
                    log.info("删除:" + ticketFile.getName() + "失败！");
                }
                if (imgFile.delete()) {
                    log.info("删除:" + imgFile.getName() + "成功！");
                } else {
                    log.info("删除:" + imgFile.getName() + "失败！");
                }
                /*if (textFile.delete()) {
                    log.info("删除:" + textFile.getName() + "成功！");
                } else {
                    log.info("删除:" + textFile.getName() + "失败！");
                }*/
            }

            return resultJSON.getString("media_id");
        } catch (Exception e) {
            log.info("-----异常------click获取推广二维码事件");
        }
        return null;
    }


}
